# SlenderQL
SlenderQL - Missing library for working with raw SQL in Python/psycopg

<img align="left" width="440" height="180" alt="Missing raw SQL tooling for python" src="https://github.com/user-attachments/assets/7f714119-e764-4427-b1b4-43051ead4a17" />
